==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/register/src/app/register.module.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {PagesModule, WLANComponent} from 'pages';
import {RouterModule, Routes} from '@angular/router';
import {FrontRegisterComponent, RegisterAppComponent} from './register.browser';
import {FrontUIModule} from 'front-ui';
import {RSBindingModule} from 'binding';

const appRoutes: Routes = [
    {
        path: 'wlan',
        component: WLANComponent
    },
    {
        path: '**',
        component: FrontRegisterComponent
    }
];


@NgModule({
    imports: [
        CommonModule,
        RSBindingModule,
        PagesModule,
        FrontUIModule,
        RouterModule.forRoot(appRoutes, { relativeLinkResolution: 'legacy' })
    ],
    declarations: [FrontRegisterComponent, RegisterAppComponent],
    bootstrap: [RegisterAppComponent],
    providers: []
})
export class RegisterModule {
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/register/src/app/register.module.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {PagesModule, WLANComponent} from 'pages';
import {RouterModule, Routes} from '@angular/router';
import {FrontRegisterComponent, RegisterAppComponent} from './register.browser';
import {FrontUIModule} from 'front-ui';
import {RSBindingModule} from 'binding';

const appRoutes: Routes = [
    {
        path: 'wlan',
        component: WLANComponent
    },
    {
        path: '**',
        component: FrontRegisterComponent
    }
];


@NgModule({
    imports: [
        CommonModule,
        RSBindingModule,
        PagesModule,
        FrontUIModule,
        RouterModule.forRoot(appRoutes, {  })
    ],
    declarations: [FrontRegisterComponent, RegisterAppComponent],
    bootstrap: [RegisterAppComponent],
    providers: []
})
export class RegisterModule {
}
